@@ -19,7 +19,7 @@ use Class::Accessor::Lite (
     ro  => [ qw(conf dbh) ],
 );
 
-our $VERSION = "0.08";
+our $VERSION = "0.09";
 
 sub load {
     my $v = Data::Validator->new(
@@ -242,7 +242,7 @@ sub _make_fixture_csv {
     my($self, $args) = $v->validate(@_);
 
     my %tmp_args     = %$args;
-    my @columns      = @{$args->{columns}};
+    my @columns      = sort @{$args->{columns}};
     my $fixture_path = File::Spec->catfile($self->conf->{fixture_path}, "$tmp_args{table}.csv");
 
     my @data = @{$args->{columns}};
